@@ -22,6 +22,6 @@ pub type text = &'static str;
 use std::io::*;
 pub fn ERROR<T>(a: &'static str) -> std::io::Result<T> { Err(Error::new(ErrorKind::Other, a)) }
 
-pub fn print_type_of<T>(_: &T) {
+pub fn type_of<T>(_: &T) {
     println!("{}", std::any::type_name::<T>())
 }
